pub struct WorkflowHandle {
pub workflow_id: String,
pub run_id: Option<String>,
pub workflow_type: String,
/* private fields */
}Fields
workflow_id: Stringrun_id: Option<String>workflow_type: StringImplementations
Sourceimpl WorkflowHandle
impl WorkflowHandle
Sourcepub async fn describe(&self) -> Result<WorkflowDescription>
pub async fn describe(&self) -> Result<WorkflowDescription>
Describe whichever run is current for this stable workflow instance.
Sourcepub async fn describe_selected_run(&self) -> Result<WorkflowDescription>
pub async fn describe_selected_run(&self) -> Result<WorkflowDescription>
Describe the run identity originally selected by this handle.
pub async fn signal<T: Serialize>( &self, signal_name: &str, input: T, ) -> Result<Value>
Sourcepub async fn signal_selected_run<T: Serialize>(
&self,
signal_name: &str,
input: T,
) -> Result<Value>
pub async fn signal_selected_run<T: Serialize>( &self, signal_name: &str, input: T, ) -> Result<Value>
Signal only if this handle’s selected run is still current.
Sourcepub async fn cancel(
&self,
options: WorkflowCommandOptions,
) -> Result<WorkflowCommandResult>
pub async fn cancel( &self, options: WorkflowCommandOptions, ) -> Result<WorkflowCommandResult>
Request cooperative cancellation of whichever run is current.
Sourcepub async fn cancel_selected_run(
&self,
options: WorkflowCommandOptions,
) -> Result<WorkflowCommandResult>
pub async fn cancel_selected_run( &self, options: WorkflowCommandOptions, ) -> Result<WorkflowCommandResult>
Request cancellation only if this handle’s selected run is still current.
Sourcepub async fn terminate(
&self,
options: WorkflowCommandOptions,
) -> Result<WorkflowCommandResult>
pub async fn terminate( &self, options: WorkflowCommandOptions, ) -> Result<WorkflowCommandResult>
Forcefully terminate whichever run is current.
Sourcepub async fn terminate_selected_run(
&self,
options: WorkflowCommandOptions,
) -> Result<WorkflowCommandResult>
pub async fn terminate_selected_run( &self, options: WorkflowCommandOptions, ) -> Result<WorkflowCommandResult>
Terminate only if this handle’s selected run is still current.
Sourcepub async fn query<T: Serialize>(
&self,
query_name: &str,
input: T,
) -> Result<Value>
pub async fn query<T: Serialize>( &self, query_name: &str, input: T, ) -> Result<Value>
Execute a named, read-only query against this workflow.
Sourcepub async fn query_selected_run<T: Serialize>(
&self,
query_name: &str,
input: T,
) -> Result<Value>
pub async fn query_selected_run<T: Serialize>( &self, query_name: &str, input: T, ) -> Result<Value>
Query only if this handle’s selected run is still current.
Sourcepub async fn result(&self, options: WorkflowResultOptions) -> Result<Value>
pub async fn result(&self, options: WorkflowResultOptions) -> Result<Value>
Await the final terminal outcome of the current continue-as-new chain.
Sourcepub async fn result_selected_run(
&self,
options: WorkflowResultOptions,
) -> Result<Value>
pub async fn result_selected_run( &self, options: WorkflowResultOptions, ) -> Result<Value>
Await only the run identity originally selected by this handle.